{% extends "base_site.html" %}

{% block title %}Articles for {{ day|date }}{% endblock %}

{% block content %}

<h1>Articles for {{ day|date }}</h1>

{% if object_list %}
    {% for article in object_list %}
    <div class="article">
        <a href="{{ article.get_absolute_url }}">{{ article.headline }}"</a>
    </div>
    {% endfor %}
{% else %}
<p>No articles were found.</p>
{% endif %}
<p><a href="{% url pl-article-list 1 %}">View all articles</a></p>

{% endblock %}
