{% extends "base_site.html" %}

{% block title %}All Articles{% endblock %}

{% block content %}

<h1>All Articles</h1>

{% if object_list %}
    {% for article in object_list %}
    <div class="article">
        <a href="{{ article.get_absolute_url }}">{{ article.headline }}</a>
    </div>
    {% endfor %}
{% else %}
<p>No articles were found.</p>
{% endif %}

{% endblock %}
