{% extends "base_site.html" %}

{% block title %}Articles for {{ year }}{% endblock %}

{% block content %}

<h1>Articles for {{ year }}</h1>

{% if object_list %}
    {% for article in object_list %}
    <div class="article">
        <h2>{{ article.headline }}</h2>
        <div class="article-summary">{{ article.summary }}</div>
        <div class="article-body">{{ article.body }}</div>
        <div class="article-pubdate">{{ article.pub_date|date:"M d Y" }}</div>
    </div>
    {% endfor %}
{% else %}
<p>No articles were found.</p>
{% endif %}
{% endblock %}

